@@ -1,8 +1,17 @@
+"""
+.. module:: FocalSet
+    :platform: Unix, Windows
+    :synopsis: A useful module indeed.
+
+.. moduleauthor:: Noelia Rico <noeliarico@uniovi.es>
+
+"""
+
 import numpy as np
 
 class FocalSet:
     
-    """Class for representing the focal sets associated to a Frame of Discerment
+    """Class for representing the focal sets associated to a frame of discerment.
     """
 
     def __init__(self, fod, bpa, fe = None):
@@ -10,12 +19,16 @@ class FocalSet:
 
         :param fod: FrameOfDiscernment for which the focal set is defined
         :type fod: FrameOfDiscernment
-        :param bpa: dictionary associating subset
+        :param bpa: This parameter can be given using two different types:
+            1) dict: associating each subsest with the basic probability assigments
+            2) ndarray: if this type is used then the  giving the indexes of the e
         :type bpa: dict, np.array
         """     
         
         # self.bpas is a dictionary containing the elements and it assigned bpa
         
+        #TODO if bpa is dict y fe is not None 
+        
         if fod == None:
             raise ValueError("The focal set must be associated with a frame of discernment.")
         else:
@@ -70,5 +83,17 @@ class FocalSet:
         of the focal set is a subset of the items in the frame of discernment.
         """
         
+    def get_bpa(self, subset):
+        
+        if isinstance(subset, (str)):
+            return self.fes.get(subset)
+        elif isinstance(subset, (int)):
+            return self.fes.values()[subset]
+        else:
+            raise TypeError("subset must be a string representing a subset or an index.")
+    
+    def __repr__(self):
+        return "Items {} \nFocal set {} \n".format(self.fod.items, self.bpas)
+        
     def __str__(self):
-        return "Items {} \n Focal set {} \n".format(self.fod.items, self.bpas)
\ No newline at end of file
+        return "Items {} \nFocal set {} \n".format(self.fod.items, self.bpas)
\ No newline at end of file
